##  Key Concepts
  * Activator: A field on fact sheet that is used to activate other fields or relations based on the value it holds. Only a single select or multi select field can be an activator .
  * Activating value: It is the value in the activator field that triggers the appearance of activated attribute.
  * Activated attribute: This is the field or relation that becomes active when a specific activating value in the activator is selected.
